searchData={"items":[{"type":"module","title":"Forecastle","doc":"Documentation for `Forecastle`.","ref":"Forecastle.html"},{"type":"function","title":"Forecastle.post_assemble/1","doc":"","ref":"Forecastle.html#post_assemble/1"},{"type":"function","title":"Forecastle.pre_assemble/1","doc":"","ref":"Forecastle.html#pre_assemble/1"},{"type":"function","title":"Forecastle.steps/1","doc":"","ref":"Forecastle.html#steps/1"},{"type":"task","title":"mix compile.appup","doc":"Compiles appup files into the application's ebin folder.","ref":"Mix.Tasks.Compile.Appup.html"},{"type":"task","title":"mix forecastle.relup","doc":"Generate a relup file between releases.\n\n`castle.relup` will generate a relup between a `target` release and\nany number of other releases. The paths specifed in the options should\nbe the paths to `.rel` files (but without the .rel extension)","ref":"Mix.Tasks.Forecastle.Relup.html"},{"type":"task","title":"Command-line options: - mix forecastle.relup","doc":"- `--target` - the path to the .rel file in the target release\n  - `--fromto` - the path to the .rel file from a previous release\n  - `--upfrom` - the path to the .rel file from a previous release\n  - `--downto` - the path to the .rel file from a previous release\n  - `--outdir` - the directory to write the relup. Defaults to the current directory\n\nThe `--fromto`, `--upfrom` and `--downto` switches may be specified zero or more\ntimes and have the following behaviour:\n\n  - `--fromto` generates both upgrade and downgrade instructions\n  - `--upfrom` generates only upgrade instructions\n  - `--downto` generates only downgrade instructions","ref":"Mix.Tasks.Forecastle.Relup.html#module-command-line-options"},{"type":"extras","title":"Forecastle","doc":"# Forecastle\n\nBuild-time support for hot-code upgrades.\n\n`Forecastle` provides build-time support for the generation of releases that correctly support hot-code \nupgrades. This includes:\n\n  - Copying appup and relup files into place.\n  - Organising the generated release structure so that it's ready for hot-code upgrades.\n  - Replacing the shell script with one that supports release unpacking and installtion\n\nAdditionally, `Forecastle` ships with a appup compiler and a mix task for relup generation.","ref":"readme.html"},{"type":"extras","title":"Installation - Forecastle","doc":"`Forecastle` is not intended to be taken as a direct dependency.  Most applications should prefer to\ntake a dependency on [Castle](https://hexdocs.pm/castle/readme.html) directly which will, in turn \ntake a build-time dependency on `Forecastle`.\n\nFor projects that don't define a release, but use the `appup` compiler, it's sufficient to \nbring `Castle` in as a build-time dependency:\n\n```elixir\ndef deps do\n  [\n    {:castle, \"~> 0.3.0\", runtime: false}\n  ]\nend\n```\n\nFor projects that _do_ define one or more releases, `Castle` should be brought in\nas a runtime dependency:\n\n```elixir\ndef deps do\n  [\n    {:castle, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Integration - Forecastle","doc":"`Forecastle` integrates into the steps of the release assembly process. It requires\nthat the `Forecastle.pre_assemble/1` and `Forecastle.post_assemble/1` functions are\nplaced around the `:assemble` step, e.g.:\n\n```elixir\ndefp releases do\n  [\n    myapp: [\n      include_executables_for: [:unix],\n      steps: [&Forecastle.pre_assemble/1, :assemble, &Forecastle.post_assemble/1, :tar]\n    ]\n  ]\nend\n```","ref":"readme.html#integration"},{"type":"extras","title":"Build Time Support - Forecastle","doc":"The following steps shape the release at build-time:","ref":"readme.html#build-time-support"},{"type":"extras","title":"Pre-assembly - Forecastle","doc":"In the pre-assembly step:\n\n  - The default evaluation of runtime configuration is disabled. `Forecastle` will\n    do its own equivalent expansion into `sys.config` prior to system start,\n    first with `runtime.exs` (if it exists) and then with any Config Providers.\n  - A 'preboot' boot script is created that starts only `Forecastle` and its\n    dependencies. This is used only during the aforementioned expansion.\n\nThe system is then assembled under the `:assemble` step as normal.","ref":"readme.html#pre-assembly"},{"type":"extras","title":"Post-assembly - Forecastle","doc":"In the post-assembly step:\n\n  - The `sys.config` generated from build-time configuration is copied to \n    `build.config`.\n  - The shell-script in the `bin` folder is replaced with one that provides\n    additional commands to manage releases.\n  - Any `runtime.exs` is copied into the version path of the release.\n  - The generated _name.rel_ is copied into the `releases` folder as _name-vsn.rel_.\n  - Any `relup` file is copied into the version path of the release.","ref":"readme.html#post-assembly"},{"type":"extras","title":"The Appup Compiler - Forecastle","doc":"You are responsible for writing the [appup](https://www.erlang.org/doc/man/appup.html)\nscripts for your application, but `Forecastle` will copy the appup into the `ebin` folder\nfor you. The steps are as follows:\n\n1. Write a file, in _Elixir form_, describing the application upgrade. e.g.:\n   ```elixir\n   # You can call the file what you like, e.g. appup.exs,\n   {\n    '0.1.1', # Code is eval'd so can also: to_charlist(Mix.Project.config[:version]),\n     [\n      {'0.1.0', [\n        {:update, MyApp.Server, {:advanced, []}}\n      ]}\n     ],\n     [\n      {'0.1.0', [\n        {:update, MyApp.Server, {:advanced, []}}\n      ]}\n     ]\n   }\n   ```\n   This file will typically be checked in to SCM.\n2. Add the appup file to the Mix project definition in mix.exs and add the\n   `:appup` compiler.\n   ```elixir\n   # Mix.exs\n   def project do\n     [\n       appup: \"appup.exs\", # Relative to the project root.\n       compilers: Mix.compilers() ++ [:appup]\n     ]\n   end\n   ```","ref":"readme.html#the-appup-compiler"},{"type":"extras","title":"Relup Generation - Forecastle","doc":"Forecastle contains a mix task, `forecastle.relup`, that simplifies the generation of\nthe relup file. Assuming you have two _unpacked_ releases e.g. `0.1.0` and `0.1.1` \nand you wish to generate a relup between them:\n\n```shell\n> mix forecastle.relup --target myapp/releases/0.1.1/myapp --fromto myapp/releases/0.1.0/myapp\n```\n\nIf the generated file is in the project root, it will be copied during \npost-assembly to the release.","ref":"readme.html#relup-generation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.3 - Jan 19, 2025 - Changelog","doc":"- 1.18 fixes","ref":"changelog.html#0-1-3-jan-19-2025"},{"type":"extras","title":"0.1.2 - Jun 10, 2023 - Changelog","doc":"- Fixes to bin script generation","ref":"changelog.html#0-1-2-jun-10-2023"},{"type":"extras","title":"0.1.1 - May 27, 2023 - Changelog","doc":"- Fix package url","ref":"changelog.html#0-1-1-may-27-2023"},{"type":"extras","title":"0.1.0 - May 27, 2023 - Changelog","doc":"- Initial revision","ref":"changelog.html#0-1-0-may-27-2023"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}